==> squint-0.0.1.tar.gz: squint-0.0.1/setup.py <==
import setuptools


#with open('README.rst') as fh:
#    long_description = fh.read()


setuptools.setup(
    name='squint',
    version='0.0.1',
    author='Shawn Brown',
    author_email='shawnbrown@users.noreply.github.com',
    description='Simple query interface for tabular data.',
    #long_description=long_description,
    #long_description_content_type='text/x-rst',
    url='https://github.com/shawnbrown/squint',
    packages=setuptools.find_packages(exclude=['docs', 'tests']),
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: Apache Software License',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.2',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: Implementation :: CPython',
        'Programming Language :: Python :: Implementation :: PyPy',
        'Topic :: Scientific/Engineering :: Information Analysis',
        'Topic :: Utilities',
    ],
    license='Apache 2.0',
    python_requires='>=2.6.7, !=3.0.*, !=3.1.*',
    install_requires=[],  # <- TODO: Break-out "get_reader" and add here.
)

==> squint-0.0.2.tar.gz: squint-0.0.2/setup.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
import setuptools


def get_long_description(path):
    with open(path) as fh:
        return fh.read()


setuptools.setup(
    # Required fields:
    name='squint',
    version='0.0.2',
    description='Simple query interface for tabular data.',
    packages=setuptools.find_packages(exclude=['docs', 'tests']),

    # Recommended fields:
    url='https://github.com/shawnbrown/squint',
    author='Shawn Brown',
    author_email='shawnbrown@users.noreply.github.com',

    # Other fields:
    install_requires=[
        'get-reader[excel,dbf]',
    ],
    python_requires='>=2.6.7, !=3.0.*, !=3.1.*',
    long_description=get_long_description('README.rst'),
    long_description_content_type='text/x-rst',
    license='Apache 2.0',
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: Apache Software License',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.2',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: Implementation :: CPython',
        'Programming Language :: Python :: Implementation :: PyPy',
        'Topic :: Scientific/Engineering :: Information Analysis',
        'Topic :: Utilities',
    ],
)
